@@ -34,5 +34,5 @@ reclist <- function(...) {
 }
 
 allreclist <- function(...) {
-  structure(list(...), class = "rematch_allrecords")
+  new_rematch_allrecords(list(...))
 }
